==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fil/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'I-kumperma ang Maramihang Pagdelete ng mga Assets',
  'bulk_delete_help'	=> 'Surrin ang mga asset para sa maramihing pagdelete sa ibaba. Kapag nai-delete na, ang mga asset na ito ay pwedeng maibalik sa dati, pero hindi na ito maiugnay sa kahit sinong user na nakatalaga nito.',
  'bulk_delete_warn'	=> 'Ikaw ay mag-delete ng :asset_count na mga asset.',
	'bulk_update'		=> 'Ang Maramihang Asset na Nai-update',
	'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang asset nang sabay-sabay. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago. ',
	'bulk_update_warn'	=> 'Ikaw ay mag-delete ng :asset_count assets.',
    'checkedout_to'		=> 'I-check Out Sa',
    'checkout_date'		=> 'Ang Petsa ng Pagcheck-out',
    'checkin_date'		=> 'Ang Petsa ng Pag-checkin',
    'checkout_to'		=> 'Mag-check out sa',
    'cost'				=> 'Ang Halaga ng Pagbili',
    'create'			=> 'Magsagawa ng Asset',
    'date'				=> 'Ang Petsa ng Pagbili',
    'depreciation'	    => 'Ang Depresasyon',
    'depreciates_on'	=> 'Ma-depreciate Sa',
    'default_location'	=> 'I-default ang Lakasyon',
    'eol_date'			=> 'Ang Petsa ng EOL',
    'eol_rate'			=> 'Ang Halaga ng EOL',
    'expected_checkin'  => 'Ang Inaasahang Petsa ng Pag-checkin',
    'expires'			=> 'Mawalan ng Bisa',
    'fully_depreciated'	=> 'Ganap nang Na-depreciate',
    'help_checkout'		=> 'Kung nais mong italaga ang asset na ito sa madaling panahon, piliin ang "Ready to Deploy" mula sa listahan ng katangian sa itaas. ',
    'mac_address'		=> 'Ang MAC address',
    'manufacturer'		=> 'Ang Tagapagsagawa',
    'model'				=> 'Ang modelo',
    'months'			=> 'mga buwan',
    'name'				=> 'Ang Pangalan ng Asset',
    'notes'				=> 'Ang mga Palatandaan',
    'order'				=> 'Ang Numero ng Order',
    'qr'				=> 'Ang Code ng QR',
    'requestable'		=> 'Ang mga gumagamit ay pwedeng mag-rekwest ng asset na ito',
    'select_statustype'	=> 'Pumili ng Tipo ng Katayuan',
    'serial'			=> 'Ang Seryal',
    'status'			=> 'Ang Katayuan',
    'tag'				=> 'Ang Tag ng Asset',
    'update'			=> 'Ang Update sa Asset',
    'warranty'			=> 'Ang Warantiya',
		'warranty_expires'		=> 'Nag-expire na ang Warantiya',
    'years'				=> 'mga taon',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fil/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'I-kumperma ang Maramihang Pagdelete ng mga Assets',
  'bulk_delete_help'	=> 'Surrin ang mga asset para sa maramihing pagdelete sa ibaba. Kapag nai-delete na, ang mga asset na ito ay pwedeng maibalik sa dati, pero hindi na ito maiugnay sa kahit sinong user na nakatalaga nito.',
  'bulk_delete_warn'	=> 'Ikaw ay mag-delete ng :asset_count na mga asset.',
    'bulk_update'		=> 'Ang Maramihang Asset na Nai-update',
    'bulk_update_help'	=> 'Ang form na ito ay nagbibigay sa iyo ng pahintulot para mag-update ng maramihang asset nang sabay-sabay. Lagyan lamang ang mga field na gusto mong baguhin. Anumang mga field na blangko ay mananatiling walang pagbabago. ',
    'bulk_update_warn'	=> 'Ikaw ay mag-delete ng :asset_count assets.',
    'checkedout_to'		=> 'I-check Out Sa',
    'checkout_date'		=> 'Ang Petsa ng Pagcheck-out',
    'checkin_date'		=> 'Ang Petsa ng Pag-checkin',
    'checkout_to'		=> 'Mag-check out sa',
    'cost'				=> 'Ang Halaga ng Pagbili',
    'create'			=> 'Magsagawa ng Asset',
    'date'				=> 'Ang Petsa ng Pagbili',
    'depreciation'	    => 'Ang Depresasyon',
    'depreciates_on'	=> 'Ma-depreciate Sa',
    'default_location'	=> 'I-default ang Lakasyon',
    'eol_date'			=> 'Ang Petsa ng EOL',
    'eol_rate'			=> 'Ang Halaga ng EOL',
    'expected_checkin'  => 'Ang Inaasahang Petsa ng Pag-checkin',
    'expires'			=> 'Mawalan ng Bisa',
    'fully_depreciated'	=> 'Ganap nang Na-depreciate',
    'help_checkout'		=> 'Kung nais mong italaga ang asset na ito sa madaling panahon, piliin ang "Ready to Deploy" mula sa listahan ng katangian sa itaas. ',
    'mac_address'		=> 'Ang MAC address',
    'manufacturer'		=> 'Ang Tagapagsagawa',
    'model'				=> 'Ang modelo',
    'months'			=> 'mga buwan',
    'name'				=> 'Ang Pangalan ng Asset',
    'notes'				=> 'Ang mga Palatandaan',
    'order'				=> 'Ang Numero ng Order',
    'qr'				=> 'Ang Code ng QR',
    'requestable'		=> 'Ang mga gumagamit ay pwedeng mag-rekwest ng asset na ito',
    'select_statustype'	=> 'Pumili ng Tipo ng Katayuan',
    'serial'			=> 'Ang Seryal',
    'status'			=> 'Ang Katayuan',
    'tag'				=> 'Ang Tag ng Asset',
    'update'			=> 'Ang Update sa Asset',
    'warranty'			=> 'Ang Warantiya',
        'warranty_expires'		=> 'Nag-expire na ang Warantiya',
    'years'				=> 'mga taon',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
